| Title: | Visualise experimental designs from edibble as ggplot graphics |
|---|---|
| Description: | Visualisation of designs as ggplot graphics. |
| Authors: | Emi Tanaka [aut, cre] (ORCID: <https://orcid.org/0000-0002-1455-259X>) |
| Maintainer: | Emi Tanaka <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-07-05 08:34:34 UTC |
| Source: | https://github.com/emitanaka/deggust |
ggplot2 of an edibble designAuto plot or ggplot2 of an edibble design
## S3 method for class 'edbl_table' autoplot( .edibble, title = NULL, aspect_ratio = 1, shape = "circle", text = FALSE, image = NULL, fill = NULL, node = NULL, horizontal = TRUE )## S3 method for class 'edbl_table' autoplot( .edibble, title = NULL, aspect_ratio = 1, shape = "circle", text = FALSE, image = NULL, fill = NULL, node = NULL, horizontal = TRUE )
.edibble |
An edibble desgin, an edibble table or an edibble graph. |
title |
The title of the plot. By default it is the name of the edibble design if available. |
aspect_ratio |
The aspect ratio of the graph. |
shape |
The shape of the unit. |
text |
A logical value of whether to show the text or not. Alternatively,
it can be a |
image |
An image to use instead of |
fill |
A character vector of variable names to display. Only a maximum of three variables are allowed. Currently, it's assumed that the the variables are discrete. In general, it's assumed that the variables are treatment variables. |
node |
A character vector of variable names. It's assumed that the variables are units. |
horizontal |
A logical value indicating whether the display should be optimized for horizontal display (default) or vertical display. Not yet implemented. |
... |
Unused at the moment. |
A ggplot object.
Change selected scale where multiple scales of same aesthetic exist
scale_aes_select(i, f, ...)scale_aes_select(i, f, ...)
i |
An integer denoting the scale number. |
f |
The scale function or the scale object. |
... |
The arguments to the scale function |
scale_fills
scale_aes_select(1, ggplot2::scale_fill_manual, values = c("red", "white", "blue")) scale_aes_select(1, ggplot2::scale_fill_manual(values = c("red", "white", "blue")))scale_aes_select(1, ggplot2::scale_fill_manual, values = c("red", "white", "blue")) scale_aes_select(1, ggplot2::scale_fill_manual(values = c("red", "white", "blue")))
This function has the same argument as the corresponding ggplot2 scale
functions where the index after the aesthetic name is omitted from the function.
E.g. scale_fill1_binned has the same argument as scale_filled_binned.
Where there is multiple fill scales, the index after the aesthetic name
determines which fill scale is modified.
scale_fill1_binned(...) scale_fill2_binned(...) scale_fill3_binned(...) scale_fill1_brewer(...) scale_fill2_brewer(...) scale_fill3_brewer(...) scale_fill1_continuous(...) scale_fill2_continuous(...) scale_fill3_continuous(...) scale_fill1_date(...) scale_fill2_date(...) scale_fill3_date(...) scale_fill1_datetime(...) scale_fill2_datetime(...) scale_fill3_datetime(...) scale_fill1_discrete(...) scale_fill2_discrete(...) scale_fill3_discrete(...) scale_fill1_manual(...) scale_fill2_manual(...) scale_fill3_manual(...)scale_fill1_binned(...) scale_fill2_binned(...) scale_fill3_binned(...) scale_fill1_brewer(...) scale_fill2_brewer(...) scale_fill3_brewer(...) scale_fill1_continuous(...) scale_fill2_continuous(...) scale_fill3_continuous(...) scale_fill1_date(...) scale_fill2_date(...) scale_fill3_date(...) scale_fill1_datetime(...) scale_fill2_datetime(...) scale_fill3_datetime(...) scale_fill1_discrete(...) scale_fill2_discrete(...) scale_fill3_discrete(...) scale_fill1_manual(...) scale_fill2_manual(...) scale_fill3_manual(...)
... |
The arguments for the corresponding scale function. |
scale_aes_select